@@ -13,5 +13,5 @@ def __determine_default_folder() -> bool:
 
 DEFAULT_FOLDER = "." if __determine_default_folder() else ".."
 
-DEFAULT_CONFIG_FILE = path.join(DEFAULT_FOLDER, CONFIG_FILE_NAME)
+DEFAULT_CONFIG_FILE_PATH = path.join(DEFAULT_FOLDER, CONFIG_FILE_NAME)
 CHECK_FOR_UPDATE_URL = "https://alivecode.ca/aliot/py/versions"
